is_lock_screen2 library
Functions
-
isLockScreen(
) → Future< bool?> - Returns whether the device is likely on the lock screen.
-
isLockScreenOrThrow(
) → Future< bool> - Returns whether the device is likely on the lock screen.
Exceptions / Errors
- IsLockScreenException
- An exception thrown when the lock-screen state cannot be read.